Name:           stapler
Version:        1.236
Release:        1%{?dist}
Summary:        Stapler Java web framework
# Project is licensed mostly under 2-clause BSD license
# It contains following ASL 2.0 licensed files:
# groovy/src/main/java/org/kohsuke/stapler/jelly/groovy/SimpleTemplateParser.java
# groovy/src/main/java/org/kohsuke/stapler/jelly/groovy/JellyBuilder.java (partly under ASL 2.0)
License:        BSD and ASL 2.0
URL:            http://stapler.kohsuke.org/
BuildArch:      noarch

# ./create-tarball.sh
Source0:        stapler-%{version}-clean.tar.gz
# Stapler/Jenkins guys don't want to add whole ASL 2.0 license
# text to the repository. Their opinion is that having short ASL 2.0 notice
# in affected files is enough
Source1:        http://www.apache.org/licenses/LICENSE-2.0.txt

# We don't have maven-jellydoc-plugin
Patch0:         0001-Remove-jellydoc-annotations.patch
# We do not bundle classes from other projects, fix that
# (this need some testing)
Patch1:         0001-Use-XmlChars-class-from-external-jar.patch
Patch2:         0001-Use-unbundled-class-from-glassfish-jaxb.patch
# not really needed now
Patch3:         servlet31.patch

BuildRequires:  maven-local
BuildRequires:  mvn(com.google.code.findbugs:jsr305)
BuildRequires:  mvn(com.google.guava:guava)
BuildRequires:  mvn(com.jcraft:jzlib)
BuildRequires:  mvn(commons-beanutils:commons-beanutils)
BuildRequires:  mvn(commons-discovery:commons-discovery)
BuildRequires:  mvn(commons-fileupload:commons-fileupload)
BuildRequires:  mvn(commons-io:commons-io)
BuildRequires:  mvn(com.sun.xml.bind:jaxb-impl)
BuildRequires:  mvn(com.sun.xml.txw2:txw2)
BuildRequires:  mvn(dom4j:dom4j)
BuildRequires:  mvn(javax.servlet:servlet-api)
BuildRequires:  mvn(javax.servlet:jsp-api)
BuildRequires:  mvn(junit:junit)
BuildRequires:  mvn(org.apache.maven.plugins:maven-release-plugin)
BuildRequires:  mvn(org.apache.tomcat:tomcat-el-api)
BuildRequires:  mvn(org.codehaus.groovy:groovy18-all:1.8)
BuildRequires:  mvn(org.jenkins-ci:annotation-indexer)
BuildRequires:  mvn(org.jenkins-ci:commons-jelly)
BuildRequires:  mvn(org.jvnet.localizer:localizer)
BuildRequires:  mvn(org.jvnet:tiger-types)
BuildRequires:  mvn(org.kohsuke.metainf-services:metainf-services)
BuildRequires:  mvn(org.kohsuke:pom:pom:)
BuildRequires:  mvn(org.kohsuke.stapler:json-lib)
BuildRequires:  mvn(org.mockito:mockito-all)
BuildRequires:  mvn(org.ow2.asm:asm)
BuildRequires:  mvn(xerces:xercesImpl)


%description
Stapler is a library that "staples" your application objects to URLs,
making it easier to write web applications. The core idea of Stapler
is to automatically assign URLs for your objects, creating an intuitive
URL hierarchy.

%package        jsp
Summary:        JSP module for %{name}

%description    jsp
This package contains %{summary}.

%package        jelly
Summary:        Jelly module for %{name}

%description    jelly
This package contains %{summary}.

%package        groovy
Summary:        Groovy module for %{name}

%description    groovy
This package contains %{summary}.

%package        parent
Summary:        Parent POM file for %{name}

%description    parent
This package contains parent POM file for %{name}.

%package        javadoc
Summary:        Javadoc for %{name}

%description    javadoc
This package contains the API documentation for %{name}.


%prep
%setup -q -n %{name}-%{name}-parent-%{version}


cp %{SOURCE1} LICENSE

%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1

sed -i 's/org.kohsuke.asm5/org.objectweb.asm/' core/src/main/java/org/kohsuke/stapler/ClassDescriptor.java

# Missing org.jruby-rack:jruby-rack
%pom_disable_module jruby
# Missing org.zeroturnaround:jr-sdk
%pom_disable_module jrebel

# Use groovy with shaded asm3
%pom_remove_dep :groovy-all core
%pom_add_dep org.codehaus.groovy:groovy18-all:1.8 core
%pom_remove_dep :groovy-all groovy
%pom_add_dep org.codehaus.groovy:groovy18-all:1.8 groovy


# Build against asm4
%pom_remove_dep :asm5 core
%pom_add_dep org.ow2.asm:asm core

# Provided by JDK
%pom_remove_dep :javax.annotation-api core
# Unavailable
%pom_remove_dep org.codehaus.mojo:extra-enforcer-rules

# Annotations removed by patch1, we don't need this anymore
%pom_remove_dep ":jellydoc-annotations" jelly

# Use original dom4j, not forked version
%pom_xpath_replace "pom:dependency[pom:artifactId[text()='dom4j']]/pom:groupId" \
  "<groupId>dom4j</groupId>" jelly

# We don't need this
%pom_remove_plugin :animal-sniffer-maven-plugin
# No need for this plugin without org.codehaus.mojo:extra-enforcer-rules
%pom_remove_plugin :maven-enforcer-plugin

# We don't have these plugins
%pom_remove_plugin :maven-jellydoc-plugin

# Replacement for unbundled classes
%pom_add_dep xerces:xercesImpl core
%pom_add_dep com.sun.xml.bind:jaxb-impl core

# maven-site-plugin generates R on unavailable artifact org.kohsuke:doxia-module-markdown
%pom_remove_plugin :maven-site-plugin

%build
# Tests require jetty 6
%mvn_build -s -f

%install
%mvn_install


%files -f .mfiles-stapler
%license LICENSE
%files jsp -f .mfiles-stapler-jsp
%files jelly -f .mfiles-stapler-jelly
%files groovy -f .mfiles-stapler-groovy
%files parent -f .mfiles-stapler-parent
%license LICENSE
%files javadoc -f .mfiles-javadoc
# rpmlint complains about this file. It's automatically generated,
# but without proper shebang
%exclude %{_javadocdir}/%{name}/javadoc.sh
%license LICENSE


%changelog
* Tue Apr 14 2015 Mikolaj Izdebski <mizdebsk@redhat.com> - 1.236-1
- Update to upstream version 1.236

* Mon Feb 02 2015 Michal Srb <msrb@redhat.com> - 1.234-1
- Update to upstream release 1.234

* Mon Nov 10 2014 Michal Srb <msrb@redhat.com> - 1.233-1
- Update to upstream version 1.233

* Fri Oct 10 2014 Michal Srb <msrb@redhat.com> - 1.231-1
- Update to upstream version 1.231

* Mon Sep 29 2014 Michal Srb <msrb@redhat.com> - 1.230-1
- Update to upstream version 1.230

* Fri Sep 19 2014 Michal Srb <msrb@redhat.com> - 1.229-1
- Update to upstream version 1.229

* Fri Aug 22 2014 msrb@redhat.com - 1.228-1
- Update to upstream version 1.228

* Mon Jun 23 2014 Michal Srb <msrb@redhat.com> - 1.227-1
- Update to upstream version 1.227

* Tue Jun 10 2014 Michal Srb <msrb@redhat.com> - 1.226-1
- Update to upstream version 1.226

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.225-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Wed Apr 23 2014 Michal Srb <msrb@redhat.com> - 1.225-1
- Update to upstream version 1.225

* Wed Feb 26 2014 Michal Srb <msrb@redhat.com> - 1.224-1
- Update to upstream version 1.224

* Wed Feb 19 2014 Michal Srb <msrb@redhat.com> - 1.223-6
- Build against proper json-lib library

* Fri Jan 10 2014 Michal Srb <msrb@redhat.com> - 1.223-5
- Remove unneeded patch

* Thu Jan 09 2014 Michal Srb <msrb@redhat.com> - 1.223-4
- Port to asm4

* Thu Jan 09 2014 Michal Srb <msrb@redhat.com> - 1.223-3
- Use groovy with shaded asm3

* Mon Jan 06 2014 Michal Srb <msrb@redhat.com> - 1.223-2
- Remove unneeded dep: findbugs (Resolves: rhbz#1049907)

* Fri Nov 29 2013 Michal Srb <msrb@redhat.com> - 1.223-1
- Update to upstream version 1.223

* Wed Oct 30 2013 Michal Srb <msrb@redhat.com> - 1.222-1
- Update to upstream version 1.222

* Tue Oct 15 2013 Michal Srb <msrb@redhat.com> - 1.221-2
- Remove R on org.kohsuke:doxia-module-markdown

* Mon Oct 14 2013 Michal Srb <msrb@redhat.com> - 1.221-1
- Update to upstream version 1.221

* Mon Sep 02 2013 Michal Srb <msrb@redhat.com> - 1.218-1
- Update to upstream version 1.218

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.209-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Wed May 29 2013 Michal Srb <msrb@redhat.com> - 1.209-2
- Exclude javadoc.sh file from javadoc

* Mon May 06 2013 Michal Srb <msrb@redhat.com> - 1.209-1
- Update to upstream version 1.209

* Mon May 06 2013 Michal Srb <msrb@redhat.com> - 1.207-1
- Initial package

